Blob Blame History Raw
# HG changeset patch
# User Franziskus Kiefer <franziskuskiefer@gmail.com>
# Date 1575483231 0
#      Wed Dec 04 18:13:51 2019 +0000
# Node ID c1fad130dce2081a5d6ce9f539c72d999f59afce
# Parent  a9ba652046e634ccb4ca21a43dd6d76858e20d62
Bug 1594933 - disable libnssdbm by default; keep build on CI, r=jcj

Disale libnssdbm by default and add flag to enable it in builds.
On CI a build and certs test with enabled legacy DB are added.

Note that for some reason the coverage build fails. I have no idea why. I'm open for ideas.

Differential Revision: https://phabricator.services.mozilla.com/D54673

diff -r a9ba652046e6 -r c1fad130dce2 tests/common/init.sh
--- a/tests/common/init.sh	Tue Dec 03 23:27:28 2019 +0000
+++ b/tests/common/init.sh	Wed Dec 04 18:13:51 2019 +0000
@@ -651,9 +651,9 @@
 
     RELOAD_CRL=1
 
-    # if test mode isn't set, test scripts default to expecting dbm
+    # if test mode isn't set, test scripts default to expecting sql
     if [ "${TEST_MODE}" = "" ]; then
-        NSS_DEFAULT_DB_TYPE="dbm"
+        NSS_DEFAULT_DB_TYPE=${NSS_DEFAULT_DB_TYPE:-"sql"}
         export NSS_DEFAULT_DB_TYPE
     fi
 
diff -r a9ba652046e6 -r c1fad130dce2 tests/remote/Makefile
--- a/tests/remote/Makefile	Tue Dec 03 23:27:28 2019 +0000
+++ b/tests/remote/Makefile	Wed Dec 04 18:13:51 2019 +0000
@@ -56,7 +56,7 @@
 TEST_SHELL?=$$HOME/bin/sh
 ANDROID_PORT?="2222"
 #Define the subset of tests that is known to work on Android
-NSS_CYCLES?="standard pkix upgradedb sharedb"
+NSS_CYCLES?="standard pkix sharedb"
 NSS_TESTS?="cipher lowhash libpkix cert dbtests tools sdr crmf smime ssl ocsp merge pkits chains"
 NSS_SSL_TESTS?="crl normal_normal iopr"
 NSS_SSL_RUN?="cov auth stress"
diff -r a9ba652046e6 -r c1fad130dce2 tests/all.sh
--- a/tests/all.sh	Tue Dec 03 23:27:28 2019 +0000
+++ b/tests/all.sh	Wed Dec 04 18:13:51 2019 +0000
@@ -51,10 +51,10 @@
 #   pkix         - run test suites with PKIX enabled
 #   upgradedb    - upgrade existing certificate databases to shareable
 #                  format (creates them if doesn't exist yet) and run
-#                  test suites with those databases
+#                  test suites with those databases. Requires to enable libdm.
 #   sharedb      - run test suites with shareable database format
 #                  enabled (databases are created directly to this
-#                  format)
+#                  format). This is the default and doesn't need to be run separately.
 #
 # Mandatory environment variables (to be set before testing):
 # -----------------------------------------------------------
@@ -135,7 +135,7 @@
 }
 
 ########################## run_cycle_standard ##########################
 # run test suites with dbm database (no PKIX, no sharedb)
 ########################################################################
 run_cycle_standard()
 {
@@ -144,7 +144,7 @@
     TESTS="${ALL_TESTS}"
     TESTS_SKIP="cipher libpkix sdr ocsp pkits"
 
-    NSS_DEFAULT_DB_TYPE="dbm"
+    NSS_DEFAULT_DB_TYPE=${NSS_DEFAULT_DB_TYPE:-"sql"}
     export NSS_DEFAULT_DB_TYPE
 
     run_tests
@@ -288,7 +288,7 @@
     . ./init.sh
 fi
 
-cycles="standard pkix upgradedb sharedb"
+cycles="standard pkix"
 CYCLES=${NSS_CYCLES:-$cycles}
 
 NO_INIT_SUPPORT=`certutil --build-flags |grep -cw NSS_NO_INIT_SUPPORT`
@@ -135,7 +135,7 @@
 
 ########################## run_cycle_standard ##########################
-# run test suites with dbm database (no PKIX, no sharedb)
+# run test suites with sql database (no PKIX)
 ########################################################################
 run_cycle_standard()